m_Librarian.

Author: Oleg Broytman <phd@phdru.name>.

Copyright (C) 2015-2022 PhiloSoft Design.

License: GPL.

This hopefully will be a collection of programs to index LibRusEc and
Flibusta libraries (zipfiles from torrents, actually), search and show
their contents with command-line, web interface and GUI.

| Home Page:     https://phdru.name/Software/Python/m_librarian/
| Documentation: https://phdru.name/Software/Python/m_librarian/docs/
| Russian docs:  https://phdru.name/Software/Python/m_librarian/docs/ru/
| Git repo:      https://git.phdru.name/m_librarian.git/
| Github repo:   https://github.com/phdru/m_librarian
| Issue tracker: https://github.com/phdru/m_librarian/issues

::

    pip install m_librarian
